fificord.py
===========

.. image:: https://img.shields.io/pypi/v/fificord.py.svg
   :target: https://pypi.org/project/fificord.py/
   :alt: PyPI version info

fificord.py is a better discord.py alternative.

Installing
~~~~~~~~~~

**Python 3 or higher is required**

.. code-block:: sh

    # Linux/macOS
    pip3 install -U fificord.py

    # Windows
    pip install -U fificord.py
